// atoo.c - A simple ASCII to Octal routine
// Author:   OldCoder (Robert Kiraly)
// License:  MIT/X
// Revision: 120105

//--------------------------------------------------------------------
// Overview.

// This is a small 'C' library routine and/or a "demo" program for the
// routine.

// To build the "demo" version under Linux, do this:
// cc -DDEBUG -o atoo atoo.c

// The "demo"  version takes  zero or more octal digit strings as com-
// mand-line arguments and outputs the  associated  values  as decimal
// integers.

// This  code  was written  originally  as an  educational  guide  for
// Ubuntu Nerd and Phenek.

//--------------------------------------------------------------------
// Header files.

#ifdef DEBUG
#include <stdio.h>
#endif

//--------------------------------------------------------------------
// Definitions.

#define ZERO      0             // Zero
#define CH_EOS    '\0'          // End of string
#define DIGITBOT  '0'           // Lowest  ASCII digit for radix
#define DIGITTOP  '7'           // Highest ASCII digit for radix
#define RADIX     8             // Radix

//--------------------------------------------------------------------
// Functions.

// "atoo" takes a  string of zero or more  characters as input and re-
// turns an integer.  The integer is the  value  of  the  text when it
// is interpreted  as an octal  digit string,  stopping with  the last
// octal digit. If there are no octal digits,  the  default  value  is
// zero.

int atoo (char *s)
{
    int c;                      // Input character
    int result = ZERO;          // Accumulated result

                                // Process all  characters
    while ((c = 0xFF & (int) *s++) != CH_EOS)
    {                           // Process next character
        if ((c < DIGITBOT) || (c > DIGITTOP)) break;
        result = (result * RADIX) + (c - DIGITBOT);
    }
    return result;              // Return result
}

//--------------------------------------------------------------------
// Main program.

#ifdef DEBUG
int main (int argc, char **argv)
{
    while (--argc > ZERO)       // Process all  arguments
    {                           // Process next argument
        char *v = *++argv;
        printf ("Octal %s is decimal %d\n", v, atoo (v));
    }
    return ZERO;
}
#endif
